==> plugin-kit-3.1.0.tgz: package/src/configs/tsconfig.ts <==
import {outdent} from 'outdent'
import {InjectTemplate} from '../actions/inject'
import {InitFlags} from '../actions/init'

export function tsconfigTemplate(options: {flags: InitFlags}): InjectTemplate {
  const {flags} = options

  return {
    type: 'template',
    force: flags.force,
    to: 'tsconfig.json',
    value: outdent`
      {
        "extends": "./tsconfig.settings",
        "include": ["./src", "./package.config.ts"],
        "compilerOptions": {
          "rootDir": ".",
          "jsx": "react-jsx",
          "noEmit": true
        }
      }
    `,
  }
}

export function tsconfigTemplateDist(options: {outDir: string; flags: InitFlags}): InjectTemplate {
  const {flags, outDir} = options

  return {
    type: 'template',
    force: flags.force,
    to: `tsconfig.${outDir}.json`,
    value: outdent`
      {
        "extends": "./tsconfig.settings",
        "include": ["./src"],
        "exclude": [
          "./src/**/__fixtures__",
          "./src/**/__mocks__",
          "./src/**/*.test.ts",
          "./src/**/*.test.tsx"
        ],
        "compilerOptions": {
          "rootDir": ".",
          "outDir": "./${outDir}",
          "jsx": "react-jsx",
          "emitDeclarationOnly": true
        }
      }
    `,
  }
}

export function tsconfigTemplateSettings(options: {flags: InitFlags}): InjectTemplate {
  const {flags} = options

  return {
    type: 'template',
    force: flags.force,
    to: `tsconfig.settings.json`,
    value: outdent`
      {
        "compilerOptions": {
          "moduleResolution": "node",
          "target": "esnext",
          "module": "esnext",
          "lib": ["DOM", "DOM.Iterable", "ESNext"],
          "esModuleInterop": true,
          "strict": true,
          "downlevelIteration": true,
          "declaration": true,
          "allowSyntheticDefaultImports": true,
          "skipLibCheck": true,
          "isolatedModules": true
        }
      }
    `,
  }
}

==> plugin-kit-4.0.13.tgz: package/src/configs/tsconfig.ts <==
import {outdent} from 'outdent'
import {InjectTemplate} from '../actions/inject'
import {InitFlags} from '../actions/init'

export function tsconfigTemplate(options: {flags: InitFlags}): InjectTemplate {
  const {flags} = options

  return {
    type: 'template',
    force: flags.force,
    to: 'tsconfig.json',
    value: outdent`
      {
        "extends": "./tsconfig.settings",
        "include": ["./src", "./package.config.ts"]
      }
    `,
  }
}

export function tsconfigTemplateDist(options: {outDir: string; flags: InitFlags}): InjectTemplate {
  const {flags, outDir} = options

  return {
    type: 'template',
    force: flags.force,
    to: `tsconfig.${outDir}.json`,
    value: outdent`
      {
        "extends": "./tsconfig.settings",
        "include": ["./src"],
        "exclude": [
          "./src/**/__fixtures__",
          "./src/**/__mocks__",
          "./src/**/*.test.ts",
          "./src/**/*.test.tsx"
        ]
      }
    `,
  }
}

export function tsconfigTemplateSettings(options: {
  outDir: string
  flags: InitFlags
}): InjectTemplate {
  const {flags, outDir} = options

  return {
    type: 'template',
    force: flags.force,
    to: `tsconfig.settings.json`,
    value: outdent`
      {
        "compilerOptions": {
          "rootDir": ".",
          "outDir": "./${outDir}",

          "target": "esnext",
          "jsx": "preserve",
          "module": "preserve",
          "moduleResolution": "bundler",
          "esModuleInterop": true,
          "resolveJsonModule": true,
          "moduleDetection": "force",
          "strict": true,
          "allowSyntheticDefaultImports": true,
          "skipLibCheck": true,
          "forceConsistentCasingInFileNames": true,
          "isolatedModules": true,

          // Don't emit by default, pkg-utils will ignore this when generating .d.ts files
          "noEmit": true
        }
      }
    `,
  }
}
